@@ -35,7 +35,7 @@ use Carp qw( croak );
 use Log::Any qw($log);
 use JSON;
 use AsposeCellsCloud::ApiClient;
-use AsposeCellsCloud::Object::CellsDocumentProperty;
+
 use base "Class::Data::Inheritable";
 
 __PACKAGE__->mk_classdata('method_documentation' => {});
@@ -505,92 +505,6 @@ sub post_export {
     return $_response_object;
 }
 
-#
-# post_import
-#
-# 
-# 
-# @param File $file File to upload (required)
-# @param string $object_type  (required)
-# @param string $format  (required)
-{
-    my $params = {
-    'file' => {
-        data_type => 'hash',
-        description => 'File to upload',
-        required => '1',
-    },
-    'import_option' => {
-        data_type => 'String',
-        description => '',
-        required => '1',
-    },
-    };
-    __PACKAGE__->method_documentation->{ 'post_import' } = { 
-    	summary => '',
-        params => $params,
-        returns => 'FilesResult',
-        };
-}
-# @return FilesResult
-#
-sub post_import {
-    my ($self, %args) = @_;
-
-    # verify the required parameter 'file' is set
-    unless (exists $args{'file'}) {
-      croak("Missing the required parameter 'file' when calling post_import");
-    }
-
-    # verify the required parameter 'object_type' is set
-    unless (exists $args{'import_option'}) {
-      croak("Missing the required parameter 'import_option' when calling post_import");
-    }
-
-    # parse inputs
-    my $_resource_path = '/cells/import';
-
-    my $_method = 'POST';
-    my $query_params = {};
-    my $header_params = {};
-    my $form_params = {};
-
-    # 'Accept' and 'Content-Type' header
-    my $_header_accept = $self->{api_client}->select_header_accept('application/json');
-    if ($_header_accept) {
-        $header_params->{'Accept'} = $_header_accept;
-    }
-    $header_params->{'Content-Type'} = $self->{api_client}->select_header_content_type('multipart/form-data');
-
-    $self->{api_client}->check_access_token();
-
-    my $_body_data;
-    # body params
-    if ( exists $args{'file'} ) {   
-        my $map_file =$args{'file'};
-        while ( my ($filename,$value) = each( %$map_file ) ) {
-             $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
-        }
-        if ( exists $args{'import_option'} ) {
-            $form_params->{'importoption'} =  $args{'import_option'};
-        }
-    }
-
-
-    # authentication setting, if any
-    my $auth_settings = [qw()];
-
-    # make the API Call
-    my $response = $self->{api_client}->call_api($_resource_path, $_method,
-                                           $query_params, $form_params,
-                                           $header_params, $_body_data, $auth_settings);
-    if (!$response) {
-        return;
-    }
-    my $_response_object = $self->{api_client}->deserialize('FilesResult', $response);
-    return $_response_object;
-}
-
 #
 # post_merge
 #
@@ -623,7 +537,6 @@ sub post_import {
         returns => 'FileInfo',
         };
 }
-
 # @return FileInfo
 #
 sub post_merge {
@@ -747,9 +660,21 @@ sub post_metadata {
         while ( my ($filename,$value) = each( %$map_file ) ) {
              $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
         }
-        if ( exists $args{'document_properties'} ) {
-            $form_params->{'documentproperties'} =  $args{'document_properties'};
-        }
+
+        # body params
+        # if ( exists $args{'document_properties'}) {
+            # print "1. document_properties\n";
+            # my $document_properties = 'ARRAY[';
+            # # $form_params->{'documentproperties'}  =  [ encode_json ( $args{'document_properties'}) , 'documentproperties',  {'Content_Type' => 'application/json'} ];
+            # foreach my $item ( $args{'document_properties'} ) {
+            #    document_properties .= $item->to_json();
+            #    document_properties .= ' , ';
+            # }
+            # document_properties .= ' ]';
+            # print  ($args{'document_properties'}[0])->TO_JSON();
+            # $form_params->{'documentproperties'} = $args{'document_properties'};# $self->{api_client}->deserialize('ARRAY[CellsDocumentProperty]', $args{'document_properties'} );   
+            # print "\n2. document_properties\n";          
+        # }
     }
 
     
@@ -1257,291 +1182,4 @@ sub post_watermark {
     return $_response_object;
 }
 
-#
-# post_compress
-#
-# 
-# 
-# @param File $file File to upload (required)
-# @param string $compress_level  (required)
-{
-    my $params = {
-    'file' => {
-        data_type => 'hash',
-        description => 'File to upload',
-        required => '1',
-    },
-    'compress_level' => {
-        data_type => 'int',
-        description => '',
-        required => '1',
-    },
-    };
-    __PACKAGE__->method_documentation->{ 'post_compress' } = { 
-    	summary => '',
-        params => $params,
-        returns => 'FilesResult',
-        };
-}
-# @return FilesResult
-#
-sub post_compress {
-    my ($self, %args) = @_;
-
-    # verify the required parameter 'file' is set
-    unless (exists $args{'file'}) {
-      croak("Missing the required parameter 'file' when calling post_compress");
-    }
-
-    # verify the required parameter 'text' is set
-    unless (exists $args{'compress_level'}) {
-      croak("Missing the required parameter 'compress_level' when calling post_compress");
-    }
-
-    # parse inputs
-    my $_resource_path = '/cells/compress';
-
-    my $_method = 'POST';
-    my $query_params = {};
-    my $header_params = {};
-    my $form_params = {};
-
-    # 'Accept' and 'Content-Type' header
-    my $_header_accept = $self->{api_client}->select_header_accept('application/json');
-    if ($_header_accept) {
-        $header_params->{'Accept'} = $_header_accept;
-    }
-    $header_params->{'Content-Type'} = $self->{api_client}->select_header_content_type('multipart/form-data');
-
-    # query params
-    if ( exists $args{'compress_level'}) {
-        $query_params->{'CompressLevel'} = $self->{api_client}->to_query_value($args{'compress_level'});
-    }
-
-    if ( exists $args{'file'} ) {   
-        my $map_file =$args{'file'};
-        while ( my ($filename,$value) = each( %$map_file ) ) {
-             $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
-        }
-    }
-
-    $self->{api_client}->check_access_token();
-    my $_body_data;
-    # authentication setting, if any
-    my $auth_settings = [qw()];
-
-    # make the API Call
-    my $response = $self->{api_client}->call_api($_resource_path, $_method,
-                                           $query_params, $form_params,
-                                           $header_params, $_body_data, $auth_settings);
-    if (!$response) {
-        return;
-    }
-    my $_response_object = $self->{api_client}->deserialize('FilesResult', $response);
-    return $_response_object;
-}
-
-#
-# post_replace
-#
-# 
-# 
-# @param File $file File to upload (required)
-# @param string $compress_level  (required)
-{
-    my $params = {
-    'file' => {
-        data_type => 'hash',
-        description => 'File to upload',
-        required => '1',
-    },
-    'text' => {
-        data_type => 'string',
-        description => '',
-        required => '1',
-    },
-    'newtext' => {
-        data_type => 'string',
-        description => '',
-        required => '1',
-    },
-    'password' => {
-        data_type => 'string',
-        description => '',
-        required => '0',
-    },
-     'sheet_name' => {
-        data_type => 'string',
-        description => '',
-        required => '0',
-    },
-    };
-    __PACKAGE__->method_documentation->{ 'post_replace' } = { 
-    	summary => '',
-        params => $params,
-        returns => 'FilesResult',
-        };
-}
-# @return FilesResult
-#
-sub post_replace {
-    my ($self, %args) = @_;
-
-    # verify the required parameter 'file' is set
-    unless (exists $args{'file'}) {
-      croak("Missing the required parameter 'file' when calling post_replace");
-    }
-
-    # verify the required parameter 'text' is set
-    unless (exists $args{'text'}) {
-      croak("Missing the required parameter 'text' when calling post_replace");
-    }
-    unless (exists $args{'newtext'}) {
-      croak("Missing the required parameter 'newtext' when calling post_replace");
-    }
-    # parse inputs
-    my $_resource_path = '/cells/replace';
-
-    my $_method = 'POST';
-    my $query_params = {};
-    my $header_params = {};
-    my $form_params = {};
-
-    # 'Accept' and 'Content-Type' header
-    my $_header_accept = $self->{api_client}->select_header_accept('application/json');
-    if ($_header_accept) {
-        $header_params->{'Accept'} = $_header_accept;
-    }
-    $header_params->{'Content-Type'} = $self->{api_client}->select_header_content_type('multipart/form-data');
-
-    # query params
-    if ( exists $args{'text'}) {
-        $query_params->{'text'} = $self->{api_client}->to_query_value($args{'text'});
-    }
-    if ( exists $args{'newtext'}) {
-        $query_params->{'newtext'} = $self->{api_client}->to_query_value($args{'newtext'});
-    }
-    if ( exists $args{'password'}) {
-        $query_params->{'password'} = $self->{api_client}->to_query_value($args{'password'});
-    }
-    if ( exists $args{'sheet_name'}) {
-        $query_params->{'sheetName'} = $self->{api_client}->to_query_value($args{'sheet_name'});
-    }        
-    if ( exists $args{'file'} ) {   
-        my $map_file =$args{'file'};
-        while ( my ($filename,$value) = each( %$map_file ) ) {
-             $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
-        }
-    }
-
-    $self->{api_client}->check_access_token();
-    my $_body_data;
-    # authentication setting, if any
-    my $auth_settings = [qw()];
-
-    # make the API Call
-    my $response = $self->{api_client}->call_api($_resource_path, $_method,
-                                           $query_params, $form_params,
-                                           $header_params, $_body_data, $auth_settings);
-    if (!$response) {
-        return;
-    }
-    my $_response_object = $self->{api_client}->deserialize('FilesResult', $response);
-    return $_response_object;
-}
-
-#
-# post_reverse
-#
-# 
-# 
-# @param File $file File to upload (required)
-# @param string $rotateType  (required)
-# @param string $format  (required)
-{
-    my $params = {
-    'file' => {
-        data_type => 'hash',
-        description => 'File to upload',
-        required => '1',
-    },
-    'rotate_type' => {
-        data_type => 'string',
-        description => '',
-        required => '1',
-    },
-    'format' => {
-        data_type => 'string',
-        description => '',
-        required => '1',
-    },
-    };
-    __PACKAGE__->method_documentation->{ 'post_reverse' } = { 
-    	summary => '',
-        params => $params,
-        returns => 'FilesResult',
-        };
-}
-# @return FilesResult
-#
-sub post_reverse {
-    my ($self, %args) = @_;
-
-    # verify the required parameter 'file' is set
-    unless (exists $args{'file'}) {
-      croak("Missing the required parameter 'file' when calling post_replace");
-    }
-
-    # verify the required parameter 'rotateType' is set
-    unless (exists $args{'rotate_type'}) {
-      croak("Missing the required parameter 'rotateType' when calling post_replace");
-    }
-    unless (exists $args{'format'}) {
-      croak("Missing the required parameter 'format' when calling post_replace");
-    }
-    # parse inputs
-    my $_resource_path = '/cells/reverse';
-
-    my $_method = 'POST';
-    my $query_params = {};
-    my $header_params = {};
-    my $form_params = {};
-
-    # 'Accept' and 'Content-Type' header
-    my $_header_accept = $self->{api_client}->select_header_accept('application/json');
-    if ($_header_accept) {
-        $header_params->{'Accept'} = $_header_accept;
-    }
-    $header_params->{'Content-Type'} = $self->{api_client}->select_header_content_type('multipart/form-data');
-
-    # query params
-    if ( exists $args{'rotate_type'}) {
-        $query_params->{'rotateType'} = $self->{api_client}->to_query_value($args{'rotate_type'});
-    }
-    if ( exists $args{'format'}) {
-        $query_params->{'format'} = $self->{api_client}->to_query_value($args{'format'});
-    }
-    if ( exists $args{'file'} ) {   
-        my $map_file =$args{'file'};
-        while ( my ($filename,$value) = each( %$map_file ) ) {
-             $form_params->{$filename} = [$value ,$filename,'application/octet-stream'];
-        }
-    }
-
-    $self->{api_client}->check_access_token();
-    my $_body_data;
-    # authentication setting, if any
-    my $auth_settings = [qw()];
-    
-    # make the API Call
-    my $response = $self->{api_client}->call_api($_resource_path, $_method,
-                                           $query_params, $form_params,
-                                           $header_params, $_body_data, $auth_settings);
-    if (!$response) {
-        return;
-    }
-    my $_response_object = $self->{api_client}->deserialize('FilesResult', $response);
-    return $_response_object;
-}
-
 1;
